/********************************************
** Plugins
********************************************/
// Theme switcher
(function ($) {

  $.fn.evoThemeSwitch = function(){

    var list = $(this);

    list.find('a').each(function(){
      $(this).on('click', function(){

        //switch class
        list.find('a').removeClass('active');
        $(this).addClass('active');

        // set new body class
        var id = $(this).attr('id');
        var curBodyClass = $('body').attr('class');
        $('body').removeClass(curBodyClass);
        $('body').addClass(id);

        return false; 

      });
    });
    
  };

}(jQuery));

// Droppable
(function ($) {

  $.fn.evoDroppable = function(){

    var dropzones = $(this);
    var allMenus = dropzones.find('.dropdown-menu');
    var allBtns = dropzones.find('button.trigger');

    dropzones.each(function(){

      var container = $(this);
      var btn = container.find('button.trigger');
      var menu = container.find('.dropdown-menu');

      btn.on('click', function(){

        if( menu.hasClass('open') ){

          allMenus.removeClass('open');
          allBtns.removeClass('current');

        } else {

          allMenus.removeClass('open');
          allBtns.removeClass('current');
          menu.addClass('open');
          btn.addClass('current');

        }

        return false;

      });

    });

    // Close all menus when clicking outside
    $('html').on('click', function(e){

      if( !$(e.target).closest('.droppable').length ){
        $('.droppable .dropdown-menu').removeClass('open');
        $('.droppable .trigger').removeClass('current');
      }

    });
    
  };

}(jQuery));

// Filter functionality
(function ($) {

  $.fn.evoFilterBar = function( filteredContent ){

    var filterWrap = $(this);
    var mobileToggle = filterWrap.find('.filter-selection');
    var filters = filterWrap.find('.tabs');
    var selector = filterWrap.find('.filter-selection');
    var aSpeed = 150;

    var windowWidth = function(){
      var e = window, a = 'inner';
      if (!('innerWidth' in window )) {
          a = 'client';
          e = document.documentElement || document.body;
      }
      return e[ a+'Width' ];
    };

    // Add click selection functionality
    var tabSelect = function(){

      filters.find('button').each(function(){

        var btn = $(this);

        btn.on('click', function(){

          // Set current filter ID
          var curFilter = $(this).parent('li').data('filter');

          // Hide/show proper elements
          if( curFilter == "all" ) {

            filteredContent.slideDown(200);

          } else {

            filteredContent.not('[data-party-status='+curFilter+']').slideUp(aSpeed);
            filteredContent.filter('[data-party-status='+curFilter+']').slideDown(aSpeed);

          }

          // Set current class on tab bars
          filters.find('li').removeClass('active');
          $(this).parent('li').addClass('active');

          // Set mobile list title
          selector.find('.current-filter').html( $(this).html() );

          if ( windowWidth() < 680 ){
            // Close mobile list if open
            filters.slideUp(aSpeed);
          }

        });

      });

    };

    tabSelect();

    // Expand/contract filters on mobile
    mobileToggle.on('click', function(){
      filters.slideToggle(aSpeed);
    });

    // Close all menus when clicking outside
    if( windowWidth() < 680 ){
      $('html').on('click', function(e){
        if( !$(e.target).closest(filterWrap.selector).length ){
          filters.slideUp(aSpeed);
        }
      });
    }

    // Add pending status bubble
    var pendingCount = function(){
      return filteredContent.filter('[data-party-status="pending"]').length;
    };
    if( pendingCount() > 0 ){
      $('li[data-filter="pending"] button').append( '<span class="notify-bubble-circle">' + pendingCount() + '</span>' );
    }

    // Add resize query to keep menu open when sizing up to larger screen
    $(window).resize(function(){
      if( windowWidth() >= 680 ){
        filters.show();
      }
    });
    
  };

}(jQuery));

// Toggle Party States
(function ($) {

  $.fn.evoPartyToggle = function(){

    var parties = $(this);
    var partyHeaders = parties.find('.party-header');
    var partyWrapper = parties.parents('.parties');

    // Close all
    partyWrapper.on('click', function(e){

      if( !$(e.target).closest('.party_wrap').length ){
        parties.removeClass('active');
      }

    });

    var toggleParty = function(party){

      if( party.hasClass('active') ){

        // toggle classes
        parties.removeClass('active');
        party.removeClass('active');

      } else {

        // toggle classes
        parties.removeClass('active');
        party.addClass('active');

      }

    };

    partyHeaders.on('click', function(e){
      
      var partyWrap = $(this).parents('.party_wrap');

      if( !$(e.target).closest('.button-wrapper').length ){
        toggleParty(partyWrap);
      }

    });

  };

}(jQuery));

(function ($) {

  $.fn.evoPartyRSVP = function(){
    
    var container = $(this);
    var buttons = container.find('button');

    var reSelectRSVP = function( button ){

      // Remove chosen class from wrapper
      button.parents('.button-wrapper').removeClass('chosen').addClass('pending');

    };

    buttons.on('click', function(){

      var curBtn = $(this);

      if( curBtn.parents('.button-wrapper').hasClass('chosen') ){

        // run expansion function
        reSelectRSVP( curBtn );

        // Don't let the button submit
        return false;

      }


    });

  };

}(jQuery));


/********************************************
** Hooks
********************************************/
jQuery(document).ready(function($) {

  // Theme switcher
  $('.theme_options').evoThemeSwitch();

  // Hook up all droppables
  $('.droppable').evoDroppable();

  // Mobile Tabs
  $('.filter-bar').evoFilterBar( $('.party_wrap') );

  // RSVP buttons
  $('.event_rsvp').evoPartyRSVP();

  // Toggle party list expansion
  $('.party_wrap').evoPartyToggle();

});